@@ -1715,6 +1715,35 @@ int vsi_dec_seek4(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
   return 0;
 }
 
+/**
+ * @brief OUTPUT_STREAMOFF on state drain @seek, flush all the pending OUTPUT,
+ * @param .
+ * @return .
+ */
+int vsi_dec_seek5(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg)
+{
+  vsi_v4l2m2m2_deccodec *dec =
+      (vsi_v4l2m2m2_deccodec *)(h->vsi_v4l2m2m_decoder);
+
+  HANTRO_LOG(HANTRO_LEVEL_DEBUG, "seek5: dec_capture_eos %d\n", h->dec_capture_eos);
+  vsi_dec_flush_input(h, v4l2_msg);
+
+  if (!h->dec_capture_eos) {
+    while (0 == vsi_dec_drop_pic(h));
+    dec->seek(h, v4l2_msg);
+  }
+
+  h->dec_output_last_inbuf_idx = INVALID_IOBUFF_IDX;
+  h->dec_output_act = DAEMON_QUEUE_ACT_NONE;
+  h->dec_output_state = DAEMON_QUEUE_STATE_OFF;
+  h->dec_capture_state = DAEMON_QUEUE_STATE_OFF;
+  h->dec_capture_act = DAEMON_QUEUE_ACT_DROP;
+  h->dec_eos = 0;
+  h->dec_capture_eos = 0;
+
+  return 0;
+}
+
 /**
  * @brief SOURCE_CHANGE @decode/drain, implicit drain CAPTURE queue.
  * @param .
@@ -1963,7 +1992,7 @@ v4l2_decoder_fsm_element vsi_v4l2dec_fsm_trans_table[] = {
     {DEC_SOURCE_CHANGE_EVENT,       DAEMON_DEC_STATE_DRAIN,             vsi_dec_reschange0,         DAEMON_DEC_STATE_SOURCE_CHANGE},
     {DEC_LAST_PIC_EVENT,            DAEMON_DEC_STATE_DRAIN,             vsi_dec_stop0,              DAEMON_DEC_STATE_STOPPED},
     {DEC_RECEIVE_CAPTUREON_EVENT,   DAEMON_DEC_STATE_DRAIN,             vsi_dec_drain3,             DAEMON_DEC_STATE_DRAIN},
-    {DEC_RECEIVE_OUTPUTOFF_EVENT,   DAEMON_DEC_STATE_DRAIN,             vsi_dec_stop0,              DAEMON_DEC_STATE_STOPPED},
+    {DEC_RECEIVE_OUTPUTOFF_EVENT,   DAEMON_DEC_STATE_DRAIN,             vsi_dec_seek5,              DAEMON_DEC_STATE_SEEK},
     {DEC_RECEIVE_CAPTUREOFF_EVENT,  DAEMON_DEC_STATE_DRAIN,             vsi_dec_stop4,              DAEMON_DEC_STATE_STOPPED},
     {DEC_RECEIVE_DESTROY_EVENT,     DAEMON_DEC_STATE_DRAIN,             vsi_dec_stop3,              DAEMON_DEC_STATE_DESTROYED},
     {DEC_FATAL_ERROR_EVENT,         DAEMON_DEC_STATE_DRAIN,             vsi_dec_fatal_error1,       DAEMON_DEC_STATE_STOPPED},
