@@ -331,7 +331,7 @@ v4l2_inst_dec_event mpeg4_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
   dec_input.stream = (u8 *)in_mem->virtual_address;
   dec_input.stream_bus_address = in_mem->bus_address;
   dec_input.data_len = in_mem->logical_size;
-  dec_input.pic_id = h->dec_pic_id; /*curr_pic_id*/
+  dec_input.pic_id = h->dec_in_pic_id; /*curr_pic_id*/
 
   HANTRO_LOG(HANTRO_LEVEL_INFO, "input: %p %lx stream len: %d\n",
              dec_input.stream, dec_input.stream_bus_address,
